Changelog
=========

0.0.3 (2013-05-22)
------------------

- Allow overriding the confd_path from an entry in the main config

0.0.2 (2013-04-18)
------------------

- Fix issue where main section was not always created

0.0.1 (2013-04-13)
------------------

- Initial commit
